import data
import pyglet
import state
import appstate

class ApplicationWindow(pyglet.window.Window):
	def __init__(self):
		super(ApplicationWindow, self).__init__(800, 600)
		
		self.state_manager = state.StateManager()
		self.state_manager.register_state(appstate.MenuState())
		self.state_manager.register_state(appstate.GameState())
		
	def init(self):
		self.state_manager.init_display(self.width, self.height)
		self.state_manager.init()		
		self.state_manager.push_state(appstate.MenuState.NAME)
		
		pyglet.clock.schedule_interval(self.update, 1/60.)
		
		pyglet.gl.glBlendFunc(pyglet.gl.GL_SRC_ALPHA, pyglet.gl.GL_ONE_MINUS_SRC_ALPHA)                             
		pyglet.gl.glEnable(pyglet.gl.GL_BLEND)                                                            
		pyglet.gl.glEnable(pyglet.gl.GL_LINE_SMOOTH);                                                     
		pyglet.gl.glHint(pyglet.gl.GL_LINE_SMOOTH_HINT, pyglet.gl.GL_DONT_CARE) 
		
	def cleanup(self):
		pyglet.clock.unschedule(self.update)
		
		self.state_manager.cleanup()
	
	def on_key_press(self, symbol, modifiers):
		self.state_manager.on_key_press(symbol, modifiers)

	def on_key_release(self, symbol, modifiers):
		self.state_manager.on_key_release(symbol, modifiers)
	
	def on_mouse_press(self, x, y, button, modifiers):
		self.state_manager.on_mouse_press(x, y, button, modifiers)
	
	def on_mouse_motion(self, x, y, dx, dy):
		self.state_manager.on_mouse_motion(x, y, dx, dy)
	
	def on_draw(self):
		self.clear()
		
		self.state_manager.draw()
		
	def update(self, dt):
		self.state_manager.update(dt)

def main():
    window = ApplicationWindow()
    window.init()
    
    pyglet.app.run()
    
    window.cleanup()
